<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\JsonResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;
use Illuminate\Validation\ValidationException;

class RegisteredUserController extends Controller
{
    /**
     * Handle an incoming registration request.
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request): JsonResponse
    {
        try {
            $request->validate([
                'name' => ['required', 'string', 'max:255'],
                'email' => ['required', 'string', 'email', 'max:255', 'unique:'.User::class],
                'password' => ['required', Rules\Password::defaults()],
            ]);
        } catch (ValidationException $e) {
            return new JsonResponse(['success'=> false, 'message' => $e->getMessage()], Response::HTTP_BAD_REQUEST);
        }

        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
        ]);

        event(new Registered($user));

        return new JsonResponse(['success'=> true, 'message' => 'User ' . $user->getAttribute('name') . ' Registered']);
    }

    public function checkUserTaken(Request $request): JsonResponse
    {
        $return = [];
        if ($request->request->has('email')) {
            $user = User::where('email', $request->request->get('email'))->first();
            if ($user !== NULL) $return['email'] = 'taken';
        }
        if ($request->request->has('name')) {
            $user = User::where('name', $request->request->get('name'))->first();
            if ($user !== NULL) $return['name'] = 'taken';
        }

        return new JsonResponse($return);
    }
}
